@@ -4,6 +4,7 @@ import logging
 from aiopulse.hub import Hub
 from aiopulse.elements import Roller, Room, Scene
 from aiopulse.errors import (
+    CannotConnectException,
     NotConnectedException,
     NotRunningException,
     InvalidResponseException,
@@ -14,11 +15,12 @@ __all__ = [
     "Roller",
     "Room",
     "Scene",
+    "CannotConnectException",
     "NotConnectedException",
     "NotRunningException",
     "InvalidResponseException",
 ]
-__version__ = "0.2.3"
+__version__ = "0.3.2"
 __author__ = "Alan Murray"
 
 _LOGGER = logging.getLogger(__name__)
